#!/etc/Tivoli/bin/perl

# Author: Jim Yu
# Date Created: 01/20/2000
# Last Modified: 01/24/2000


# Several 3.6.2 Language Support products depend on a tag TMF_<locale>_3.6.1
# When upgrading a TMR from 3.6 to 3.6.2 (without going through 3.6.1),
# that tag is missing. This script registers the missing tags, enabling
# installation of the Language Support products.
#

if ($#ARGV >= 0)
{
	print "usage: 362TMF03.pl\n";
	exit;
}


@locales = ( "PTBR", "DE", "IT", "JA", "ES", "ZHCN", "FR", "KO" );
chop( $tmr = `wlookup NameRegistry` );

foreach $locale ( @locales )
{
	$tmfTag = "TMF_${locale}";
	$missingTag = "${tmfTag}_3.6.1";

	# get the registered tags
	$dodo = "\"ProductInfo\" \"${tmfTag}\"";
	$result = `idlcall $tmr lookup \'${dodo}\'` ;

	if ( $result =~ /_EXCEPTION/ )
	{
		print "Language support for locale $locale not installed. Nothing done.\n";
	}
	elsif ( $result =~ /${missingTag}/ )
	{
		print "Tag $missingTag already registered. Nothing done for locale $locale.\n";
	}
	elsif ( $result =~ /} { 2 \"/ )
	{
		&addTag( $missingTag, $result );
	}
	else
	{
		print "***Unexpected situation. Nothing done for tag $missingTag.\n";
		print "   idlcall returned: $result\n";
	}
}




#
# addTag adds the missing tag
#
sub addTag
{
	# unregister tag
	$unreg = `wregister -ur ProductInfo $tmfTag` ;

	# build new value
	$newValue = $_[1];
	$newValue =~ s/} { 2 (\".*)(} } })/} { 3 $1\"$_[0]\" $2/;

	# add new value
	$fofo = "\"ProductInfo\" " . $newValue ;
	$reg = `idlcall $tmr add_value \'${fofo}\'` ;
	if ( $? == 0 )
	{
		print "Tag $_[0] has been registered. Update completed.\n";
	}
	else
	{
		print "***Failed to register tag $_[0].\n";
		print "   idlcall returned: $reg\n";
	}

}

